==> php-phalcon5_5.1.2.orig.tar.gz: cphalcon-5.1.2/tests/unit/Encryption/Security/JWT/Builder/GetSetNotBeforeCest.php <==
<?php

/**
 * This file is part of the Phalcon Framework.
 *
 * For the full copyright and license information, please view the LICENSE.md
 * file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Phalcon\Tests\Unit\Encryption\Security\JWT\Builder;

use Phalcon\Encryption\Security\JWT\Builder;
use Phalcon\Encryption\Security\JWT\Exceptions\ValidatorException;
use Phalcon\Encryption\Security\JWT\Signer\Hmac;
use UnitTester;

/**
 * Class GetSetNotBeforeCest
 *
 * @package Phalcon\Tests\Unit\Encryption\Security\JWT\Builder
 */
class GetSetNotBeforeCest
{
    /**
     * Unit Tests Phalcon\Encryption\Security\JWT\Builder :: getNotBefore()/setNotBefore()
     *
     * @param UnitTester $I
     *
     * @author Phalcon Team <team@phalcon.io>
     * @since  2020-09-09
     */
    public function encryptionSecurityJWTBuilderGetSetNotBefore(UnitTester $I)
    {
        $I->wantToTest('Encryption\Security\JWT\Builder - getNotBefore()/setNotBefore()');

        $signer  = new Hmac();
        $builder = new Builder($signer);

        $I->assertNull($builder->getNotBefore());

        $return = $builder->setNotBefore(4);
        $I->assertInstanceOf(Builder::class, $return);

        $I->assertSame(4, $builder->getNotBefore());
    }

    /**
     * Unit Tests Phalcon\Encryption\Security\JWT\Builder :: setNotBefore() - exception
     *
     * @param UnitTester $I
     *
     * @author Phalcon Team <team@phalcon.io>
     * @since  2020-09-09
     */
    public function encryptionSecurityJWTBuilderSetNotBefore(UnitTester $I)
    {
        $I->wantToTest('Encryption\Security\JWT\Builder - setNotBefore() - exception');

        $I->expectThrowable(
            new ValidatorException(
                "Invalid Not Before"
            ),
            function () {
                $signer  = new Hmac();
                $builder = new Builder($signer);
                $future  = strtotime("now") + 1000;
                $return  = $builder->setNotBefore($future);
            }
        );
    }
}

==> php-phalcon5_5.6.1.orig.tar.gz: cphalcon-5.6.1/tests/unit/Encryption/Security/JWT/Builder/GetSetNotBeforeCest.php <==
<?php

/**
 * This file is part of the Phalcon Framework.
 *
 * For the full copyright and license information, please view the LICENSE.md
 * file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Phalcon\Tests\Unit\Encryption\Security\JWT\Builder;

use Phalcon\Encryption\Security\JWT\Builder;
use Phalcon\Encryption\Security\JWT\Exceptions\ValidatorException;
use Phalcon\Encryption\Security\JWT\Signer\Hmac;
use UnitTester;

/**
 * Class GetSetNotBeforeCest
 *
 * @package Phalcon\Tests\Unit\Encryption\Security\JWT\Builder
 */
class GetSetNotBeforeCest
{
    /**
     * Unit Tests Phalcon\Encryption\Security\JWT\Builder ::
     * getNotBefore()/setNotBefore()
     *
     * @param UnitTester $I
     *
     * @author Phalcon Team <team@phalcon.io>
     * @since  2020-09-09
     */
    public function encryptionSecurityJWTBuilderGetSetNotBefore(UnitTester $I)
    {
        $I->wantToTest('Encryption\Security\JWT\Builder - getNotBefore()/setNotBefore()');

        $signer  = new Hmac();
        $builder = new Builder($signer);

        $I->assertNull($builder->getNotBefore());

        $return = $builder->setNotBefore(4);
        $I->assertInstanceOf(Builder::class, $return);

        $I->assertSame(4, $builder->getNotBefore());
    }

    /**
     * Unit Tests Phalcon\Encryption\Security\JWT\Builder :: setNotBefore() -
     * exception
     *
     * @param UnitTester $I
     *
     * @author Phalcon Team <team@phalcon.io>
     * @since  2020-09-09
     */
    public function encryptionSecurityJWTBuilderSetNotBefore(UnitTester $I)
    {
        $I->wantToTest('Encryption\Security\JWT\Builder - setNotBefore() - exception');

        $I->expectThrowable(
            new ValidatorException(
                "Invalid Not Before"
            ),
            function () {
                $signer  = new Hmac();
                $builder = new Builder($signer);
                $future  = strtotime("now") + 1000;
                $return  = $builder->setNotBefore($future);
            }
        );
    }
}
